@@ -1,5 +1,5 @@
 /*
- * $Id: avrcore.c,v 1.86 2008/01/07 14:26:25 joerg_wunsch Exp $
+ * $Id: avrcore.c,v 1.87 2008/03/16 21:14:07 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -841,12 +841,12 @@ avr_core_irq_get_pending (AvrCore *core)
 
 /** \brief Raises an irq by adding it's data to the irq_pending list. */
 void
-avr_core_irq_raise (AvrCore *core, int irq)
+avr_core_irq_raise (AvrCore *core, unsigned int irq)
 {
     IntVect *irq_ptr = &core->irq_vtable[irq];
 
 #if !defined(DISABLE_IRQ_MESSAGES)
-    avr_message ("Raising irq # %d [%s at 0x%x]\n", irq, irq_ptr->name,
+    avr_message ("Raising irq # %u [%s at 0x%x]\n", irq, irq_ptr->name,
                  irq_ptr->addr * 2);
 #endif
     core->irq_pending = irq_list_add (core->irq_pending, irq_ptr);
