@@ -1,5 +1,5 @@
 /*
- * $Id: register.c,v 1.35 2004/01/30 07:09:56 troth Exp $
+ * $Id: register.c,v 1.36 2008/01/06 22:38:19 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -58,9 +58,9 @@
  *
 \****************************************************************************/
 
-static inline uint8_t sreg_read (VDevice *dev, int addr);
-static inline void sreg_write (VDevice *dev, int addr, uint8_t val);
-static inline void sreg_reset (VDevice *dev);
+static uint8_t sreg_read (VDevice *dev, int addr);
+static void sreg_write (VDevice *dev, int addr, uint8_t val);
+static void sreg_reset (VDevice *dev);
 static void sreg_add_addr (VDevice *dev, int addr, char *name, int rel_addr,
                            void *data);
 
@@ -103,27 +103,27 @@ sreg_destroy (void *sreg)
     vdev_destroy (sreg);
 }
 
-extern inline uint8_t sreg_get (SREG *sreg);
+extern uint8_t sreg_get (SREG *sreg);
 
-extern inline void sreg_set (SREG *sreg, uint8_t val);
+extern void sreg_set (SREG *sreg, uint8_t val);
 
-extern inline uint8_t sreg_get_bit (SREG *sreg, int bit);
+extern uint8_t sreg_get_bit (SREG *sreg, int bit);
 
-extern inline void sreg_set_bit (SREG *sreg, int bit, int val);
+extern void sreg_set_bit (SREG *sreg, int bit, int val);
 
-static inline uint8_t
+static uint8_t
 sreg_read (VDevice *dev, int addr)
 {
     return sreg_get ((SREG *)dev);
 }
 
-static inline void
+static void
 sreg_write (VDevice *dev, int addr, uint8_t val)
 {
     sreg_set ((SREG *)dev, val);
 }
 
-static inline void
+static void
 sreg_reset (VDevice *dev)
 {
     display_io_reg (SREG_IO_REG, 0);
@@ -143,9 +143,9 @@ sreg_add_addr (VDevice *dev, int addr, char *name, int rel_addr, void *data)
  *
 \****************************************************************************/
 
-static inline uint8_t gpwr_read (VDevice *dev, int addr);
-static inline void gpwr_write (VDevice *dev, int addr, uint8_t val);
-static inline void gpwr_reset (VDevice *dev);
+static uint8_t gpwr_read (VDevice *dev, int addr);
+static void gpwr_write (VDevice *dev, int addr, uint8_t val);
+static void gpwr_reset (VDevice *dev);
 
 GPWR *
 gpwr_new (void)
@@ -179,17 +179,17 @@ gpwr_destroy (void *gpwr)
     vdev_destroy (gpwr);
 }
 
-extern inline uint8_t gpwr_get (GPWR *gpwr, int reg);
+extern uint8_t gpwr_get (GPWR *gpwr, int reg);
 
-extern inline void gpwr_set (GPWR *gpwr, int reg, uint8_t val);
+extern void gpwr_set (GPWR *gpwr, int reg, uint8_t val);
 
-static inline uint8_t
+static uint8_t
 gpwr_read (VDevice *dev, int addr)
 {
     return gpwr_get ((GPWR *)dev, addr);
 }
 
-static inline void
+static void
 gpwr_write (VDevice *dev, int addr, uint8_t val)
 {
     gpwr_set ((GPWR *)dev, addr, val);
